@@ -7,9 +7,8 @@ import sys
 import tempfile
 import unittest
 
-import six
-
 from nose2 import discover, util
+import six
 
 HERE = os.path.abspath(os.path.dirname(__file__))
 SUPPORT = os.path.join(HERE, "functional", "support")
@@ -276,7 +275,7 @@ class RedirectStdStreams(object):
         sys.stderr = self.old_stderr
 
 
-# mock multprocessing Connection
+# mock multiprocessing Connection
 class Conn(object):
     def __init__(self, items):
         self.items = items
@@ -309,3 +308,9 @@ def windows_ci_skip(f):
         platform.system() == "Windows" and environment_is_ci(),
         "This test is skipped on Windows in CI",
     )(f)
+
+
+def _method_name(name="test"):
+    """Get an extra method name for Python 3.11"""
+    # https://github.com/python/cpython/issues/58473
+    return r"\." + name if sys.version_info >= (3, 11) else ""
